Hacking
=======

Fork me on `bitbucket.org`_ or put your issues to the `issue tracker`_.

.. .. image:: https://secure.travis-ci.org/icemac/icemac.truncatetext.png

.. _`bitbucket.org` : https://bitbucket.org/icemac/icemac.truncatetext
.. _`issue tracker` : https://bitbucket.org/icemac/icemac.truncatetext/issues
